require 'spec_helper'

describe Guard::Unity do

  let (:runner) { Guard::Unity.Runner }

  describe '#initialize' do

    context 'when no options are provided' do

      it 'has :test_on_start set to true' do
        expect(subject.options[:test_on_start]).to be_true
      end

      it 'has :project_path set' do
        expect(subject.options[:project_path]).to eq(Dir.pwd)
      end

      it 'has :unity set' do
        expect(subject.options[:unity]).to eq('/Applications/Unity/Unity.app/Contents/MacOS/Unity')
      end

      it 'has :results_path set' do
        expect(subject.options[:results_path]).to eq(Dir.pwd + '/UnitTestResults.xml')
      end
      
    end

    context 'when options are provided' do

      subject do
        Guard::Unity.new test_on_start: false, project_path: 'foo', unity: 'bar', results_path: 'foo-bar'
      end

      it 'has :test_on_start set to false' do
        expect(subject.options[:test_on_start]).to be_false
      end

      it 'has :project_path set' do
        expect(subject.options[:project_path]).to eq('foo')
      end

      it 'has :unity set' do
        expect(subject.options[:unity]).to eq('bar')
      end

      it 'has :results_path set' do
        expect(subject.options[:results_path]).to eq('foo-bar')
      end

    end
  end

  describe '#start' do

    context 'with :run_on_start set to false' do

      subject do
        Guard::Unity.new test_on_start: false
      end

      it 'should\'t call #run' do
        subject.should_not_receive :run
        ::Guard::UI.should_receive(:info)
        subject.start
      end
    end

    context 'with :run_on_start set to true' do

      subject do
        Guard::Unity.new test_on_start: true
      end

      it 'should call #run' do
        subject.runner.should_receive :run
        ::Guard::UI.should_receive(:info)
        subject.start
      end

    end
  end

  describe '#run_all' do

    subject do
      Guard::Unity.new
    end

    it 'should call #run_all' do
      subject.runner.should_receive :run
      subject.run_all
    end

  end

  describe '#run_on_modification' do

    subject do
      Guard::Unity.new
    end

    it 'should call #run_all' do
      subject.runner.should_receive :run
      subject.run_on_modifications []
    end

  end

end